@@ -7,17 +7,20 @@ import warnings
 
 
 class MissingOptionalDependency(Exception):
-    """ Exception raised when a optional dependency is needed by not found. """
+    """Exception raised when a optional dependency is needed by not found."""
+
     pass
 
 
 class DeprecatedAttribute(DeprecationWarning):
-    """ Warning category for an attribute which has been renamed/moved.  """
+    """Warning category for an attribute which has been renamed/moved."""
+
     pass
 
 
 class DeprecatedFunctionName(DeprecationWarning):
-    """ Warning category for a function which has been renamed/moved. """
+    """Warning category for a function which has been renamed/moved."""
+
     pass
 
 
@@ -41,10 +44,15 @@ def _deprecated_alias(func, old_name, new_name):
         warning when the called.
 
     """
+
     def wrapper(*args, **kwargs):
         warnings.warn(
-            ("{0} has been deprecated and will be removed in future " +
-             "versions of Py-ART, pleases use {1}. ").format(
-                 old_name, new_name), category=DeprecatedFunctionName)
+            (
+                "{0} has been deprecated and will be removed in future "
+                + "versions of Py-ART, pleases use {1}. "
+            ).format(old_name, new_name),
+            category=DeprecatedFunctionName,
+        )
         return func(*args, **kwargs)
+
     return wrapper
